@@ -23,21 +23,22 @@
 #include "basicindexingjob.h"
 #include "database.h"
 #include "xapiandocument.h"
-#include "lib/baloo_xattr_p.h"
 
 #include <QFileInfo>
 #include <QDateTime>
 #include <QStringList>
 
-#include <kfilemetadata/typeinfo.h>
+#include <KFileMetaData/TypeInfo>
+#include <KFileMetaData/UserMetaData>
 #include <QDebug>
 
 using namespace Baloo;
 
-BasicIndexingJob::BasicIndexingJob(QSqlDatabase* db, const FileMapping& file, const QString& mimetype)
-    : m_sqlDb(db)
-    , m_file(file)
+BasicIndexingJob::BasicIndexingJob(const FileMapping& file, const QString& mimetype,
+                                   bool onlyBasicIndexing)
+    : m_file(file)
     , m_mimetype(mimetype)
+    , m_onlyBasicIndexing(onlyBasicIndexing)
     , m_id(0)
 {
 }
@@ -48,28 +49,21 @@ BasicIndexingJob::~BasicIndexingJob()
 
 bool BasicIndexingJob::index()
 {
-    if (m_file.id() == 0) {
-        if (!m_file.create(*m_sqlDb)) {
-            qWarning() << "Cannot create fileMapping for" << m_file.url();
-            return false;
-        }
-    }
-
     QFileInfo fileInfo(m_file.url());
 
     XapianDocument doc;
-    doc.addTerm(m_mimetype, "M");
+    doc.addBoolTerm(m_mimetype, QLatin1String("M"));
     doc.indexText(fileInfo.fileName(), 1000);
-    doc.indexText(fileInfo.fileName(), "F", 1000);
+    doc.indexText(fileInfo.fileName(), QLatin1String("F"), 1000);
 
     // Modified Date
     QDateTime mod = fileInfo.lastModified();
     const QString dtm = mod.toString(Qt::ISODate);
 
-    doc.addBoolTerm(dtm, "DT_M");
-    doc.addBoolTerm(mod.date().year(), "DT_MY");
-    doc.addBoolTerm(mod.date().month(), "DT_MM");
-    doc.addBoolTerm(mod.date().day(), "DT_MD");
+    doc.addBoolTerm(dtm, QLatin1String("DT_M"));
+    doc.addBoolTerm(mod.date().year(), QLatin1String("DT_MY"));
+    doc.addBoolTerm(mod.date().month(), QLatin1String("DT_MM"));
+    doc.addBoolTerm(mod.date().day(), QLatin1String("DT_MD"));
 
     const QString timeTStr = QString::number(mod.toTime_t());
     doc.addValue(0, timeTStr);
@@ -79,52 +73,63 @@ bool BasicIndexingJob::index()
     QVector<KFileMetaData::Type::Type> tList = typesForMimeType(m_mimetype);
     Q_FOREACH (KFileMetaData::Type::Type type, tList) {
         QString tstr = KFileMetaData::TypeInfo(type).name().toLower();
-        doc.addBoolTerm(tstr, "T");
+        doc.addBoolTerm(tstr, QLatin1String("T"));
     }
 
     if (fileInfo.isDir()) {
-        doc.addBoolTerm("folder", "T");
+        doc.addBoolTerm(QStringLiteral("Tfolder"));
 
         // This is an optimization for folders. They do not need to go through
         // file indexing, so there are no indexers for folders
-        doc.addBoolTerm("Z2");
+        doc.addBoolTerm(QLatin1String("Z2"));
+    }
+    else if (m_onlyBasicIndexing) {
+        // This is to prevent indexing if option in config is set to do so
+        doc.addBoolTerm(QLatin1String("Z2"));
     }
     else {
-        doc.addBoolTerm("Z1");
+        doc.addBoolTerm(QLatin1String("Z1"));
     }
 
-    //
-    // X-Attr terms
-    //
-    QString val;
-
-    baloo_getxattr(m_file.url(), QLatin1String("user.xdg.tags"), &val);
-    if (!val.isEmpty()) {
-        QStringList tags = val.split(QLatin1Char(','), QString::SkipEmptyParts);
-        Q_FOREACH (const QString& tag, tags) {
-            doc.indexText(tag, QLatin1String("TA"));
-            doc.addBoolTerm(QLatin1String("TAG-") + tag);
-        }
-    }
-
-    val.clear();
-    baloo_getxattr(m_file.url(), QLatin1String("user.baloo.rating"), &val);
-    if (!val.isEmpty()) {
-        doc.addBoolTerm(val, QLatin1String("R"));
-    }
-
-    val.clear();
-    baloo_getxattr(m_file.url(), QLatin1String("user.xdg.comment"), &val);
-    if (!val.isEmpty()) {
-        doc.indexText(val, QLatin1String("C"));
-    }
+    indexXAttr(m_file.url(), doc);
 
     m_id = m_file.id();
     m_doc = doc.doc();
     return true;
 }
 
-QVector<KFileMetaData::Type::Type> BasicIndexingJob::typesForMimeType(const QString& mimeType) const
+bool BasicIndexingJob::indexXAttr(const QString& url, XapianDocument& doc)
+{
+    bool modified = false;
+
+    KFileMetaData::UserMetaData userMetaData(url);
+
+    QStringList tags = userMetaData.tags();
+    if (!tags.isEmpty()) {
+        Q_FOREACH (const QString& tag, tags) {
+            doc.indexText(tag, QStringLiteral("TA"));
+            doc.addBoolTerm(QStringLiteral("TAG-") + tag);
+        }
+
+        modified = true;
+    }
+
+    int rating = userMetaData.rating();
+    if (rating) {
+        doc.addBoolTerm(QString::number(rating), QStringLiteral("R"));
+        modified = true;
+    }
+
+    QString comment = userMetaData.userComment();
+    if (!comment.isEmpty()) {
+        doc.indexText(comment, QStringLiteral("C"));
+        modified = true;
+    }
+
+    return modified;
+}
+
+QVector<KFileMetaData::Type::Type> BasicIndexingJob::typesForMimeType(const QString& mimeType)
 {
     using namespace KFileMetaData;
     QVector<Type::Type> types;
@@ -159,6 +164,7 @@ QVector<KFileMetaData::Type::Type> BasicIndexingJob::typesForMimeType(const QStr
         // Microsoft
         typeMapper.insert(QLatin1String("text/plain"), Type::Document);
         typeMapper.insert(QLatin1String("application/msword"), Type::Document);
+        typeMapper.insert(QLatin1String("application/x-scribus"), Type::Document);
         typeMapper.insert(QLatin1String("application/vnd.ms-powerpoint"), Type::Document);
         typeMapper.insert(QLatin1String("application/vnd.ms-powerpoint"), Type::Presentation);
         typeMapper.insert(QLatin1String("application/vnd.ms-excel"), Type::Document);
