@@ -23,27 +23,17 @@
 #include "kio_tags.h"
 
 #include <QUrl>
-#include <kio/global.h>
-#include <klocale.h>
-#include <kio/job.h>
-#include <KUser>
 #include <QDebug>
+
 #include <KLocalizedString>
-#include <kio/netaccess.h>
-#include <KComponentData>
-#include <KUrl>
+#include <KUser>
+#include <kio/job.h>
 
 #include <QCoreApplication>
 #include <QDateTime>
-#include <QDBusConnection>
-#include <QDBusConnectionInterface>
-
-#include <sys/types.h>
-#include <unistd.h>
+#include <QDir>
 
 #include "file.h"
-#include "filemodifyjob.h"
-#include "filefetchjob.h"
 #include "taglistjob.h"
 
 #include "query.h"
@@ -98,22 +88,22 @@ void TagsProtocol::listDir(const QUrl& url)
         job->exec();
 
         Q_FOREACH (const QString& tag, job->tags()) {
-            listEntry(createUDSEntryForTag(tag), false);
+            listEntry(createUDSEntryForTag(tag));
         }
 
-        listEntry(KIO::UDSEntry(), true);
         finished();
         return;
     }
 
     case TagUrl: {
         Query q;
-        q.addType("File");
-        q.setTerm(Term("tag", tag));
+        q.addType(QLatin1String("File"));
+        q.setTerm(Term(QLatin1String("tag"), tag));
+        q.setSortingOption(Query::SortNone);
 
         ResultIterator it = q.exec();
         while (it.next()) {
-            const QUrl url = it.url();
+            const QUrl url = QUrl::fromLocalFile(it.filePath());
             const QString fileUrl = url.toLocalFile();
 
             // Somehow stat the file
@@ -135,11 +125,11 @@ void TagsProtocol::listDir(const QUrl& url)
             uds.insert(KIO::UDSEntry::UDS_TARGET_URL, url.url());
             uds.insert(KIO::UDSEntry::UDS_LOCAL_PATH, fileUrl);
 
-            listEntry(uds, false);
+            listEntry(uds);
         }
 
-        listEntry(KIO::UDSEntry(), true);
         finished();
+        return;
     }
 
     case FileUrl:
@@ -191,7 +181,7 @@ void TagsProtocol::stat(const QUrl& url)
     }
 }
 
-void TagsProtocol::copy(const QUrl& src, const QUrl& dest, int permissions, KIO::JobFlags flags)
+void TagsProtocol::copy(const QUrl& src, const QUrl& dest, int, KIO::JobFlags)
 {
     qDebug() << src << dest;
 
@@ -214,6 +204,8 @@ void TagsProtocol::copy(const QUrl& src, const QUrl& dest, int permissions, KIO:
         return;
 
     case FileUrl:
+        /*
+         * FIXME: Do we really need to support copy operations?
         Baloo::FileFetchJob* job = new Baloo::FileFetchJob(fileUrl);
         job->exec();
         Baloo::File file = job->file();
@@ -221,6 +213,7 @@ void TagsProtocol::copy(const QUrl& src, const QUrl& dest, int permissions, KIO:
         file.addTag(tag);
         Baloo::FileModifyJob* mjob = new Baloo::FileModifyJob(file);
         mjob->exec();
+        */
 
         finished();
         return;
@@ -287,10 +280,12 @@ void TagsProtocol::rename(const QUrl& src, const QUrl& dest, KIO::JobFlags flags
         // Yes, this is weird, but it is required
         // It is required cause the dest url is of the form tags:/tag/file_url_with_new_filename
         // So we extract the new fileUrl from the 'src', and apply the new file to the dest
-        KUrl destUrl(fileUrl);
-        destUrl.setFileName(dest.fileName());
+        QString destUrl = fileUrl;
+        int lastIndex = destUrl.lastIndexOf(QDir::separator());
+        destUrl.resize(lastIndex + 1);
+        destUrl.append(dest.fileName());
 
-        ForwardingSlaveBase::rename(fileUrl, destUrl, flags);
+        ForwardingSlaveBase::rename(QUrl(fileUrl), QUrl(destUrl), flags);
         return;
     }
     }
@@ -298,6 +293,7 @@ void TagsProtocol::rename(const QUrl& src, const QUrl& dest, KIO::JobFlags flags
 
 void TagsProtocol::del(const QUrl& url, bool isfile)
 {
+    Q_UNUSED(url)
     Q_UNUSED(isfile);
     /*
 
@@ -354,7 +350,7 @@ void TagsProtocol::mimetype(const QUrl& url)
 
     case RootUrl:
     case TagUrl:
-        mimeType("inode/directory");
+        mimeType(QLatin1String("inode/directory"));
         finished();
         return;
 
@@ -386,7 +382,7 @@ QString TagsProtocol::encodeFileUrl(const QString& url)
 }
 
 
-TagsProtocol::ParseResult TagsProtocol::parseUrl(const QUrl& url, QString& tag, QString& fileUrl, bool ignoreErrors)
+TagsProtocol::ParseResult TagsProtocol::parseUrl(const QUrl& url, QString& tag, QString& fileUrl, bool)
 {
     QString path = url.path();
     if (path.isEmpty() || path == QLatin1String("/"))
@@ -415,9 +411,10 @@ TagsProtocol::ParseResult TagsProtocol::parseUrl(const QUrl& url, QString& tag,
 
 extern "C"
 {
-    Q_DECL_EXPORT int kdemain(int, char** argv)
+    Q_DECL_EXPORT int kdemain(int argc, char** argv)
     {
-        KComponentData("kio_tags");
+        QCoreApplication app(argc, argv);
+        app.setApplicationName(QStringLiteral("kio_tags"));
         Baloo::TagsProtocol slave(argv[2], argv[3]);
         slave.dispatchLoop();
         return 0;
